@@ -1,3 +1,5 @@
+from os import environ
+
 import uvicorn
 from fastapi import FastAPI, HTTPException, Request
 from fastapi.staticfiles import StaticFiles
@@ -14,8 +16,9 @@ from pymongo.database import Database
 import dbtqdm
 from dbtqdm.args.server import TqdmArgParser
 from dbtqdm.consts import DEF_TITLE, DEF_INTERVAL, DEF_DB_PORT, DEF_HOST, DEF_PORT, DEF_DB_HOST, DEF_DB_NAME, \
-    STATS_COLLECTION
+    STATS_COLLECTION, DEF_ROOT_PATH
 
+# root_path = environ['ROOT_PATH'] if 'ROOT_PATH' in environ else ''
 app = FastAPI()
 app.mount("/static", StaticFiles(directory=f'{files(dbtqdm)}/static'), name="static")
 templates = Jinja2Templates(directory=f'{files(dbtqdm)}/templates')
@@ -29,10 +32,8 @@ def home(request: Request) -> templates.TemplateResponse:
     """ Show all the progress bar.
     :return: The home web page, which shows all the progress bars.
     """
-    # global web_title, interval
     return templates.TemplateResponse("index.html",
                                       {'title': app.web_title, 'interval': app.interval, 'request': request})
-    # return templates.get_template('index.html').render(title=web_title, interval=interval, request=request)
 
 
 @app.get(BAR_ROUTE + '/{bar_id}', response_class=HTMLResponse)
@@ -98,7 +99,7 @@ def bar_progress(db: Database, bar_id: str) -> dict:
     """ Obtain the progress bar information from MongoDB from its id.
     :param db: The database.
     :param bar_id: The bar id to remove. This id is formed by the bar name and bar name suffix.
-    :return: The
+    :return: A dictionary with the progress bar information.
     """
     bar = db[bar_id].find_one({})
     if bar and '_id' in bar:
@@ -106,9 +107,10 @@ def bar_progress(db: Database, bar_id: str) -> dict:
     return bar
 
 
-def start_server(title: str = DEF_TITLE, host: str = DEF_HOST, port: int = DEF_PORT,  db_host: str = DEF_DB_HOST,
-                 db_port: int = DEF_DB_PORT, replicaset: str = None, db_name: str = DEF_DB_NAME,
-                 user: str = '', password: str = '', cert_key_file: str = None, ca_file: str = None,
+def start_server(title: str = DEF_TITLE, host: str = DEF_HOST, port: int = DEF_PORT,  root_path: str = DEF_ROOT_PATH,
+                 db_host: str = DEF_DB_HOST, db_port: int = DEF_DB_PORT, replicaset: str = None,
+                 db_name: str = DEF_DB_NAME, user: str = '', password: str = '',
+                 cert_key_file: str = None, ca_file: str = None,
                  session_token: str = None, seconds_interval: int = DEF_INTERVAL * 1000) -> None:
     """ Start the server.
     :param title: The web page title.
@@ -125,18 +127,20 @@ def start_server(title: str = DEF_TITLE, host: str = DEF_HOST, port: int = DEF_P
     :param session_token: The database session token.
     :param seconds_interval: The interval between the web page refreshing.
     """
-    # global db, web_title, interval
     app.web_title, app.interval = title, seconds_interval
+    logger.info(f'Starting the server with this parameters:\nHost: {host}\nPort: {port}\nRoot path: {root_path}\n'
+                f'DB host: {db_host}\nDB port: {db_port}\nºReplicaset: {replicaset}\n')
+    logger.info('Starting the server with this parameters:')
     app.db = connect_database(db_host, db_port, replicaset, db_name, user, password,
                               cert_key_file, ca_file, session_token)
+    app.root_path = root_path
     uvicorn.run(app, host=host, port=port)
-    # app.run(host, port)
 
 
 def main() -> None:
     """ The main function. """
     args = TqdmArgParser()
-    start_server(args.title, args.host, args.port, args.db_host, args.db_port, args.replicaset, args.database,
+    start_server(args.title, args.host, args.port, args.root_path, args.db_host, args.db_port, args.replicaset, args.database,
                  args.user, args.password, args.cert_key_file, args.ca_file, args.session_token, args.interval)
 
 
